@@ -2,7 +2,7 @@ package Float::Truncate;
 
 use strict;
 use 5.008_005;
-our $VERSION = '0.01';
+our $VERSION = '0.03';
 use vars qw/@ISA @EXPORT @EXPORT_OK/;
 require Exporter;
 @ISA = qw(Exporter);
@@ -10,16 +10,15 @@ require Exporter;
 
 sub truncate {
     my ( $number, $length ) = @_;
-    return $number unless $length;
-
+    return $number unless defined $length;
     return sprintf "%.${length}f", $number;
 }
 
 sub truncate_force {
     my ( $number, $length ) = @_;
-    return $number unless $length;
-    
-    $length = 10 ** $length;
+    return $number unless defined $length;
+
+    $length = 10**$length;
     return int( $number * $length ) / $length;
 }
 
@@ -63,6 +62,3 @@ Copyright 2018- MC Cheung
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
-=head1 SEE ALSO
-
-=cut
